@@ -234,24 +234,12 @@ static void update_message_area(AppearanceData* data)
 
 		data->style_message_label = gtk_label_new (NULL);
 		gtk_label_set_line_wrap (GTK_LABEL (data->style_message_label), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
 		gtk_label_set_xalign (GTK_LABEL (data->style_message_label), 0.0);
-#else
-		gtk_misc_set_alignment (GTK_MISC (data->style_message_label), 0.0, 0.5);
-#endif
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 9);
-#else
-		hbox = gtk_hbox_new (FALSE, 9);
-#endif
 		icon = gtk_image_new_from_icon_name ("dialog-warning", GTK_ICON_SIZE_DIALOG);
-#if GTK_CHECK_VERSION (3, 0, 0)
 		gtk_widget_set_halign (icon, GTK_ALIGN_CENTER);
 		gtk_widget_set_valign (icon, GTK_ALIGN_START);
-#else
-		gtk_misc_set_alignment (GTK_MISC (icon), 0.5, 0.0);
-#endif
 		gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, FALSE, 0);
 		gtk_box_pack_start (GTK_BOX (hbox), data->style_message_label, TRUE, TRUE, 0);
 		content = gtk_info_bar_get_content_area (GTK_INFO_BAR (data->style_message_area));
@@ -263,43 +251,13 @@ static void update_message_area(AppearanceData* data)
 		gtk_box_pack_start (GTK_BOX (parent), data->style_message_area, FALSE, FALSE, 0);
 	}
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	if (engine != NULL)
-	{
-		gchar* message = g_strdup_printf(_("This theme will not look as intended because the required GTK+ theme engine '%s' is not installed."), engine);
-		gtk_label_set_text(GTK_LABEL(data->style_message_label), message);
-		g_free(message);
-		g_free(engine);
-
-   		if (packagekit_available())
-   		{
-     		gtk_widget_show(data->style_install_button);
-     	}
-   		else
-      	{
-      		gtk_widget_hide(data->style_install_button);
-      	}
-
-    	gtk_widget_show(data->style_message_area);
-   		gtk_widget_queue_draw(data->style_message_area);
-	}
-	else
-	{
-		gtk_widget_hide(data->style_message_area);
-	}
-#else
   gtk_widget_hide(data->style_message_area);
-#endif
 }
 
 static void
 update_color_buttons_from_string (const gchar *color_scheme, AppearanceData *data)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
   GdkRGBA colors[NUM_SYMBOLIC_COLORS];
-#else
-  GdkColor colors[NUM_SYMBOLIC_COLORS];
-#endif
   GtkWidget *widget;
   gint i;
 
@@ -309,11 +267,7 @@ update_color_buttons_from_string (const gchar *color_scheme, AppearanceData *dat
   /* now set all the buttons to the correct settings */
   for (i = 0; i < NUM_SYMBOLIC_COLORS; ++i) {
     widget = appearance_capplet_get_widget (data, symbolic_names[i]);
-#if GTK_CHECK_VERSION (3, 0, 0)
     gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (widget), &colors[i]);
-#else
-    gtk_color_button_set_color (GTK_COLOR_BUTTON (widget), &colors[i]);
-#endif
   }
 }
 
@@ -384,11 +338,7 @@ static void
 color_button_clicked_cb (GtkWidget *colorbutton, AppearanceData *data)
 {
   GtkWidget *widget;
-#if GTK_CHECK_VERSION (3, 0, 0)
   GdkRGBA color;
-#else
-  GdkColor color;
-#endif
   GString *scheme = g_string_new (NULL);
   gchar *colstr;
   gchar *old_scheme = NULL;
@@ -396,17 +346,9 @@ color_button_clicked_cb (GtkWidget *colorbutton, AppearanceData *data)
 
   for (i = 0; i < NUM_SYMBOLIC_COLORS; ++i) {
     widget = appearance_capplet_get_widget (data, symbolic_names[i]);
-#if GTK_CHECK_VERSION (3, 0, 0)
     gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (widget), &color);
-#else
-    gtk_color_button_get_color (GTK_COLOR_BUTTON (widget), &color);
-#endif
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     colstr = gdk_rgba_to_string (&color);
-#else
-    colstr = gdk_color_to_string (&color);
-#endif
     g_string_append_printf (scheme, "%s:%s\n", symbolic_names[i], colstr);
     g_free (colstr);
   }
@@ -509,7 +451,6 @@ icon_theme_changed (GSettings *settings, gchar *key, AppearanceData *data)
 			    theme_is_writable (theme));
 }
 
-#ifdef HAVE_XCURSOR
 static void
 cursor_size_changed_cb (int size, AppearanceData *data)
 {
@@ -536,13 +477,11 @@ cursor_size_scale_value_changed_cb (GtkRange *range, AppearanceData *data)
     cursor_size_changed_cb (size, data);
   }
 }
-#endif
 
 static void
 update_cursor_size_scale (MateThemeCursorInfo *theme,
                           AppearanceData *data)
 {
-#ifdef HAVE_XCURSOR
   GtkWidget *cursor_size_scale;
   GtkWidget *cursor_size_label;
   GtkWidget *cursor_size_small_label;
@@ -610,7 +549,6 @@ update_cursor_size_scale (MateThemeCursorInfo *theme,
 
   if (size != gsettings_size)
     cursor_size_changed_cb (size, data);
-#endif
 }
 
 static void
@@ -1075,10 +1013,8 @@ style_init (AppearanceData *data)
   icon_theme_changed (data->interface_settings, ICON_THEME_KEY, data);
   cursor_theme_changed (data->mouse_settings, CURSOR_THEME_KEY, data);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   GtkNotebook *style_nb = GTK_NOTEBOOK (appearance_capplet_get_widget (data, "notebook2"));
   gtk_notebook_remove_page (style_nb, 1);
-#endif
 
   w = appearance_capplet_get_widget (data, "color_scheme_message_hbox");
   gtk_widget_set_no_show_all (w, TRUE);
@@ -1091,7 +1027,6 @@ style_init (AppearanceData *data)
   settings = gtk_settings_get_default ();
   g_signal_connect (settings, "notify::gtk-color-scheme", (GCallback) color_scheme_changed, data);
 
-#ifdef HAVE_XCURSOR
   w = appearance_capplet_get_widget (data, "cursor_size_scale");
   g_signal_connect (w, "value-changed", (GCallback) cursor_size_scale_value_changed_cb, data);
 
@@ -1104,13 +1039,6 @@ style_init (AppearanceData *data)
   label = g_strdup_printf ("<small><i>%s</i></small>", gtk_label_get_text (GTK_LABEL (w)));
   gtk_label_set_markup (GTK_LABEL (w), label);
   g_free (label);
-#else
-  w = appearance_capplet_get_widget (data, "cursor_size_hbox");
-  gtk_widget_set_no_show_all (w, TRUE);
-  gtk_widget_hide (w);
-  gtk_widget_show (appearance_capplet_get_widget (data, "cursor_message_hbox"));
-  gtk_box_set_spacing (GTK_BOX (appearance_capplet_get_widget (data, "cursor_vbox")), 12);
-#endif
 
   /* connect signals */
   /* color buttons */
