@@ -495,6 +495,7 @@ foo_scroll_area_draw (GtkWidget *widget,
     scroll_area->priv->current_input = NULL;
 
     /* Finally draw the backing pixmap */
+    gtk_widget_get_allocation (widget, &widget_allocation);
     cairo_set_source_surface (widget_cr, scroll_area->priv->surface, widget_allocation.x, widget_allocation.y);
     cairo_paint (widget_cr);
 
@@ -526,6 +527,10 @@ emit_viewport_changed (FooScrollArea *scroll_area,
 		       GdkRectangle  *new_viewport,
 		       GdkRectangle  *old_viewport)
 {
+    GdkDisplay *display;
+    GdkSeat *seat;
+    GdkDevice *pointer;
+
     int px, py;
     g_signal_emit (scroll_area, signals[VIEWPORT_CHANGED], 0, 
 		   new_viewport, old_viewport);
@@ -533,7 +538,14 @@ emit_viewport_changed (FooScrollArea *scroll_area,
     if (scroll_area->priv->input_window == NULL)
 	return;
 
-    gdk_window_get_pointer (scroll_area->priv->input_window, &px, &py, NULL);
+    display = gdk_window_get_display (scroll_area->priv->input_window);
+    seat = gdk_display_get_default_seat (display);
+    pointer = gdk_seat_get_pointer (seat);
+    gdk_window_get_device_position (scroll_area->priv->input_window,
+                                    pointer,
+                                    &px,
+                                    &py,
+                                    NULL);
     
     process_event (scroll_area, FOO_MOTION, px, py);
 }
@@ -547,8 +559,6 @@ clamp_adjustment (GtkAdjustment *adj)
 					       - gtk_adjustment_get_page_size (adj)));
     else
 	gtk_adjustment_set_value (adj, 0.0);
-    
-    gtk_adjustment_changed (adj);
 }
 
 static gboolean
