@@ -6,10 +6,6 @@
 #include "eggcellrendererkeys.h"
 #include "eggaccelerators.h"
 
-#if !GTK_CHECK_VERSION(3,0,0)
-#define gtk_widget_get_preferred_size(x,y,z) gtk_widget_size_request(x,y)
-#endif
-
 #ifndef EGG_COMPILATION
 	#ifndef _
 		#define _(x) dgettext (GETTEXT_PACKAGE, x)
@@ -31,8 +27,8 @@ static GtkCellEditable *egg_cell_renderer_keys_start_editing (GtkCellRenderer
 							      GdkEvent                 *event,
 							      GtkWidget                *widget,
 							      const gchar              *path,
-							      GdkRectangle             *background_area,
-							      GdkRectangle             *cell_area,
+							      const GdkRectangle       *background_area,
+							      const GdkRectangle       *cell_area,
 							      GtkCellRendererState      flags);
 
 
@@ -44,13 +40,13 @@ static void egg_cell_renderer_keys_set_property (GObject         *object,
 						 guint            param_id,
 						 const GValue    *value,
 						 GParamSpec      *pspec);
-static void egg_cell_renderer_keys_get_size     (GtkCellRenderer *cell,
-						 GtkWidget       *widget,
-						 GdkRectangle    *cell_area,
-						 gint            *x_offset,
-						 gint            *y_offset,
-						 gint            *width,
-						 gint            *height);
+static void egg_cell_renderer_keys_get_size	(GtkCellRenderer    *cell,
+						 GtkWidget          *widget,
+						 const GdkRectangle *cell_area,
+						 gint               *x_offset,
+						 gint               *y_offset,
+						 gint               *width,
+						 gint               *height);
 
 
 enum {
@@ -343,14 +339,13 @@ static gboolean is_modifier(guint keycode)
 }
 
 static void
-egg_cell_renderer_keys_get_size (GtkCellRenderer *cell,
-				 GtkWidget       *widget,
-				 GdkRectangle    *cell_area,
-				 gint            *x_offset,
-				 gint            *y_offset,
-				 gint            *width,
-				 gint            *height)
-
+egg_cell_renderer_keys_get_size(GtkCellRenderer    *cell,
+				 GtkWidget          *widget,
+				 const GdkRectangle *cell_area,
+				 gint               *x_offset,
+				 gint               *y_offset,
+				 gint               *width,
+				 gint               *height)
 {
   EggCellRendererKeys *keys = (EggCellRendererKeys *) cell;
   GtkRequisition requisition;
@@ -382,6 +377,8 @@ static gboolean grab_key_callback(GtkWidget* widget, GdkEventKey* event, void* d
 	GdkModifierType consumed_modifiers;
 	guint upper;
 	GdkModifierType ignored_modifiers;
+	GdkDisplay *display;
+	GdkSeat *seat;
 
 	keys = EGG_CELL_RENDERER_KEYS(data);
 
@@ -467,8 +464,10 @@ static gboolean grab_key_callback(GtkWidget* widget, GdkEventKey* event, void* d
 
 	out:
 
-	gdk_keyboard_ungrab(event->time);
-	gdk_pointer_ungrab(event->time);
+	display = gtk_widget_get_display (widget);
+	seat = gdk_display_get_default_seat (display);
+
+	gdk_seat_ungrab (seat);
 
 	path = g_strdup(g_object_get_data(G_OBJECT(keys->edit_widget), EGG_CELL_RENDERER_TEXT_PATH));
 
@@ -493,9 +492,13 @@ static gboolean grab_key_callback(GtkWidget* widget, GdkEventKey* event, void* d
 static void ungrab_stuff(GtkWidget* widget, gpointer data)
 {
 	EggCellRendererKeys* keys = EGG_CELL_RENDERER_KEYS(data);
+	GdkDisplay *display;
+	GdkSeat *seat;
 
-	gdk_keyboard_ungrab(GDK_CURRENT_TIME);
-	gdk_pointer_ungrab(GDK_CURRENT_TIME);
+	display = gtk_widget_get_display (widget);
+	seat = gdk_display_get_default_seat (display);
+
+	gdk_seat_ungrab (seat);
 
 	g_signal_handlers_disconnect_by_func(G_OBJECT(keys->grab_widget), G_CALLBACK(grab_key_callback), data);
 }
@@ -549,12 +552,14 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
 				      GdkEvent             *event,
 				      GtkWidget            *widget,
 				      const gchar          *path,
-				      GdkRectangle         *background_area,
-				      GdkRectangle         *cell_area,
+				      const GdkRectangle   *background_area,
+				      const GdkRectangle   *cell_area,
 				      GtkCellRendererState  flags)
 {
   GtkCellRendererText *celltext;
   EggCellRendererKeys *keys;
+  GdkDisplay *display;
+  GdkSeat *seat;
   GtkWidget *label;
   GtkWidget *eventbox;
   GValue celltext_editable = {0};
@@ -569,18 +574,18 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
     return NULL;
   g_return_val_if_fail (gtk_widget_get_window (widget) != NULL, NULL);
 
-  if (gdk_keyboard_grab (gtk_widget_get_window (widget), FALSE,
-                         gdk_event_get_time (event)) != GDK_GRAB_SUCCESS)
-    return NULL;
+  display = gtk_widget_get_display (widget);
+  seat = gdk_display_get_default_seat (display);
 
-  if (gdk_pointer_grab (gtk_widget_get_window (widget), FALSE,
-                        GDK_BUTTON_PRESS_MASK,
-                        NULL, NULL,
-                        gdk_event_get_time (event)) != GDK_GRAB_SUCCESS)
-    {
-      gdk_keyboard_ungrab (gdk_event_get_time (event));
-      return NULL;
-    }
+  if (gdk_seat_grab (seat,
+                     gtk_widget_get_window (widget),
+                     GDK_SEAT_CAPABILITY_ALL,
+                     FALSE,
+                     NULL,
+                     event,
+                     NULL,
+                     NULL) != GDK_GRAB_SUCCESS)
+    return NULL;
 
   keys->grab_widget = widget;
 
@@ -595,11 +600,7 @@ egg_cell_renderer_keys_start_editing (GtkCellRenderer      *cell,
                              (void**) &keys->edit_widget);
 
   label = gtk_label_new (NULL);
-#if GTK_CHECK_VERSION (3, 16, 0)
   gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
 
   gtk_widget_modify_bg (eventbox, GTK_STATE_NORMAL,
                         &gtk_widget_get_style (widget)->bg[GTK_STATE_SELECTED]);
