@@ -46,21 +46,13 @@ mate_metacity_config_tool ()
     gtk_window_set_icon_name (GTK_WINDOW (dialog), "preferences-system-windows");
     gtk_window_set_default_size (GTK_WINDOW (dialog), 350, 150);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-#else
-    vbox = gtk_vbox_new (FALSE, 6);
-#endif
 
     str = g_strdup_printf ("<b>%s</b>", _("Compositing Manager"));
     widget = gtk_label_new (str);
     g_free (str);
     gtk_label_set_use_markup (GTK_LABEL (widget), TRUE);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (widget), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
-#endif
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 0);
 
     widget = gtk_check_button_new_with_label (_("Enable software _compositing window manager"));
