@@ -25,6 +25,7 @@
 #include <libmate-desktop/mate-desktop-item.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -97,7 +98,6 @@ hide_shell (AppShellData * app_data)
 {
 	gtk_window_get_position (GTK_WINDOW (app_data->main_app),
 		&app_data->main_app_window_x, &app_data->main_app_window_y);
-	/* printf("x:%d, y:%d\n", app_data->main_app_window_x, app_data->main_app_window_y); */
 	/* clear the search bar now so reshowing is fast and flicker free - BNC#283186 */
 	application_launcher_clear_search_bar (app_data);
 	gtk_widget_hide (app_data->main_app);
@@ -266,9 +266,9 @@ layout_shell (AppShellData * app_data, const gchar * filter_title, const gchar *
 	right_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
 	num_cols = SIZING_SCREEN_WIDTH_LARGE_NUMCOLS;
-	if (gdk_screen_width () <= SIZING_SCREEN_WIDTH_LARGE)
+	if (WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) <= SIZING_SCREEN_WIDTH_LARGE)
 	{
-		if (gdk_screen_width () <= SIZING_SCREEN_WIDTH_MEDIUM)
+		if (WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) <= SIZING_SCREEN_WIDTH_MEDIUM)
 			num_cols = SIZING_SCREEN_WIDTH_SMALL_NUMCOLS;
 		else
 			num_cols = SIZING_SCREEN_WIDTH_MEDIUM_NUMCOLS;
@@ -277,6 +277,7 @@ layout_shell (AppShellData * app_data, const gchar * filter_title, const gchar *
 		app_resizer_new (GTK_BOX (right_vbox), num_cols, TRUE, app_data);
 
 	sw = gtk_scrolled_window_new (NULL, NULL);
+	gtk_widget_set_vexpand (GTK_WIDGET (sw), TRUE);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC,
 		GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
@@ -415,11 +416,7 @@ create_actions_section (AppShellData * app_data, const gchar * title,
 			header = gtk_label_new (action->name);
 			gtk_label_set_line_wrap (GTK_LABEL (header), TRUE);
 			gtk_label_set_max_width_chars (GTK_LABEL (header), 0);
-#if GTK_CHECK_VERSION (3, 16, 0)
 			gtk_label_set_xalign (GTK_LABEL (header), 0.0);
-#else
-			gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
-#endif
 			launcher = nameplate_tile_new (NULL, NULL, header, NULL);
 
 			g_object_set_data (G_OBJECT (launcher), APP_ACTION_KEY, action->item);
@@ -706,11 +703,7 @@ create_application_category_sections (AppShellData * app_data)
 		GtkWidget *hbox;
 		GtkWidget *table;
 
-#if GTK_CHECK_VERSION (3, 16, 0)
 		gtk_label_set_xalign (GTK_LABEL (header), 0.0);
-#else
-		gtk_misc_set_alignment (GTK_MISC (header), 0.0, 0.5);
-#endif
 		data->group_launcher = TILE (nameplate_tile_new (NULL, NULL, header, NULL));
 		g_object_ref (data->group_launcher);
 
@@ -749,23 +742,21 @@ show_no_results_message (AppShellData * app_data, GtkWidget * containing_vbox)
 
 	if (!app_data->filtered_out_everything_widget)
 	{
-		GtkWidget *hbox;
 		GtkWidget *image;
 		GtkWidget *label;
 
-		app_data->filtered_out_everything_widget = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+		app_data->filtered_out_everything_widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+		gtk_widget_set_halign (app_data->filtered_out_everything_widget, GTK_ALIGN_CENTER);
+		gtk_widget_set_valign (app_data->filtered_out_everything_widget, GTK_ALIGN_CENTER);
 		g_object_ref (app_data->filtered_out_everything_widget);
 
-		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 		image = themed_icon_new ("face-surprise", GTK_ICON_SIZE_DIALOG);
-		gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (app_data->filtered_out_everything_widget), image, FALSE, FALSE, 0);
 
 		label = gtk_label_new (NULL);
 		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-		gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 15);
+		gtk_box_pack_start (GTK_BOX (app_data->filtered_out_everything_widget), label, TRUE, TRUE, 15);
 		app_data->filtered_out_everything_widget_label = GTK_LABEL (label);
-
-		gtk_container_add (GTK_CONTAINER (app_data->filtered_out_everything_widget), hbox);
 	}
 
 	str1 = g_markup_printf_escaped ("<b>%s</b>", app_data->filter_string);
@@ -1019,7 +1010,6 @@ check_specific_apps_hack (MateDesktopItem * item)
 			mate_desktop_item_get_string (item, MATE_DESKTOP_ITEM_CATEGORIES);
 		if (g_strrstr (categories, COMMAND_LINE_LOCKDOWN_DESKTOP_CATEGORY))
 		{
-			/* printf ("eliminating %s\n", mate_desktop_item_get_location (item)); */
 			return TRUE;
 		}
 	}
@@ -1164,7 +1154,6 @@ generate_new_apps (AppShellData * app_data)
 				if (g_hash_table_lookup (new_apps_dups, uri))
 				{
 					/* if a desktop file is in 2 or more top level categories, only show it once */
-					/* printf("Discarding Newapp duplicate:%s\n", uri); */
 					break;
 				}
 				g_hash_table_insert (new_apps_dups, (gpointer) uri, (gpointer) uri);
