@@ -43,7 +43,7 @@
 #define CALC_TEMPLATE_FILE_NAME   "empty.ots"
 #define WRITER_TEMPLATE_FILE_NAME "empty.ott"
 
-#define GTK_BOOKMARKS_FILE ".gtk-bookmarks"
+#define GTK_BOOKMARKS_FILE "bookmarks"
 
 #define TYPE_IS_RECENT(type) ((type) == BOOKMARK_STORE_RECENT_APPS || (type) == BOOKMARK_STORE_RECENT_DOCS)
 
@@ -361,8 +361,6 @@ bookmark_agent_update_from_bookmark_file (BookmarkAgent *this, GBookmarkFile *st
 
 	priv = PRIVATE (this);
 
-	libslab_checkpoint ("bookmark_agent_update_from_bookmark_file(): start updating");
-
 	items_ordered = make_items_from_bookmark_file (this, store);
 
 	g_bookmark_file_free (priv->store);
@@ -381,10 +379,7 @@ bookmark_agent_update_from_bookmark_file (BookmarkAgent *this, GBookmarkFile *st
 
 	g_list_free (items_ordered);
 
-	libslab_checkpoint ("bookmark_agent_update_from_bookmark_file(): updating internal items");
 	update_items (this);
-
-	libslab_checkpoint ("bookmark_agent_update_from_bookmark_file(): end updating");
 }
 
 void
@@ -509,7 +504,8 @@ bookmark_agent_new (BookmarkStoreType type)
 
 			priv->load_store = load_places_store;
 
-			priv->gtk_store_path = g_build_filename (g_get_home_dir (), GTK_BOOKMARKS_FILE, NULL);
+			priv->gtk_store_path = g_build_filename (g_get_user_config_dir (),
+                                                     "gtk-3.0", GTK_BOOKMARKS_FILE, NULL);
 			gtk_store_file = g_file_new_for_path (priv->gtk_store_path);
 			priv->gtk_store_monitor = g_file_monitor_file (gtk_store_file,
 								       0, NULL, NULL);
@@ -527,7 +523,7 @@ bookmark_agent_new (BookmarkStoreType type)
 			priv->user_modifiable = TRUE;
 			priv->reorderable     = FALSE;
 
-			priv->store_path = g_build_filename (g_get_home_dir (), ".recently-used.xbel", NULL);
+			priv->store_path = g_build_filename (g_get_user_data_dir (), "recently-used.xbel", NULL);
 
 			break;
 
@@ -839,9 +835,7 @@ load_xbel_store (BookmarkAgent *this)
 	if (!priv->store_path)
 		success = FALSE;
 	else {
-		libslab_checkpoint ("load_xbel_store(): start loading %s", priv->store_path);
 		success = g_bookmark_file_load_from_file (priv->store, priv->store_path, & error);
-		libslab_checkpoint ("load_xbel_store(): end loading %s", priv->store_path);
 	}
 
 	if (!success) {
@@ -855,16 +849,12 @@ load_xbel_store (BookmarkAgent *this)
 		return;
 	}
 
-	libslab_checkpoint ("load_xbel_store(): start creating items from %s", priv->store_path);
-
 	uris = g_bookmark_file_get_uris (priv->store, NULL);
 
 	for (i = 0; uris && uris [i]; ++i)
 		priv->create_item (this, uris [i]);
 
 	g_strfreev (uris);
-
-	libslab_checkpoint ("load_xbel_store(): end creating items from %s", priv->store_path);
 }
 
 static void
@@ -1073,43 +1063,40 @@ create_doc_item (BookmarkAgent *this, const gchar *uri)
 	BookmarkAgentPrivate *priv = PRIVATE (this);
 
 	gchar *uri_new = NULL;
-	gchar *path;
-	gchar *dir;
-	gchar *file;
-	gchar *template = NULL;
-	gsize  length;
-	gchar *contents;
 
+	if ((strcmp (uri, "BLANK_SPREADSHEET") == 0) || (strcmp (uri, "BLANK_DOCUMENT") == 0)) {
+		gchar *template = NULL;
+		gchar *file;
 
-	if (! (strcmp (uri, "BLANK_SPREADSHEET") && strcmp (uri, "BLANK_DOCUMENT"))) {
-		dir = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS));
-		if (! dir)
+		gchar *dir = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS));
+		if (!dir)
 			dir = g_build_filename (g_get_home_dir (), "Documents", NULL);
 
-		if (! strcmp (uri, "BLANK_SPREADSHEET")) {
+		if (strcmp (uri, "BLANK_SPREADSHEET") == 0) {
 			g_bookmark_file_set_title (priv->store, uri, "BLANK_SPREADSHEET");
 			file = g_strconcat (_("New Spreadsheet"), ".ots", NULL);
 			template = find_package_data_file (CALC_TEMPLATE_FILE_NAME);
-		}
-		else {
+		} else {
 			g_bookmark_file_set_title (priv->store, uri, "BLANK_DOCUMENT");
 			file = g_strconcat (_("New Document"), ".ott", NULL);
 			template = find_package_data_file (WRITER_TEMPLATE_FILE_NAME);
 		}
 
-		path = g_build_filename (dir, file, NULL);
-
-		if (! g_file_test (path, G_FILE_TEST_EXISTS)) {
+		gchar *path = g_build_filename (dir, file, NULL);
+		if (!g_file_test (path, G_FILE_TEST_EXISTS)) {
 			g_mkdir_with_parents (dir, 0700);
 
 			if (template != NULL) {
-				if (g_file_get_contents (template, & contents, & length, NULL))
+				gchar *contents;
+				gsize length;
+
+				if (g_file_get_contents (template, &contents, &length, NULL))
 					g_file_set_contents (path, contents, length, NULL);
 
 				g_free (contents);
-			}
-			else
+			} else {
 				fclose (g_fopen (path, "w"));
+			}
 		}
 
 		uri_new = g_filename_to_uri (path, NULL, NULL);
@@ -1120,7 +1107,7 @@ create_doc_item (BookmarkAgent *this, const gchar *uri)
 		g_free (template);
 	}
 
-	if (! uri_new)
+	if (!uri_new)
 		return;
 
 	if (libslab_strcmp (uri, uri_new))
@@ -1135,52 +1122,49 @@ create_dir_item (BookmarkAgent *this, const gchar *uri)
 	BookmarkAgentPrivate *priv = PRIVATE (this);
 
 	gchar *uri_new = NULL;
-	gchar *path;
+	gchar *path = NULL;
 	gchar *name = NULL;
 	gchar *icon = NULL;
 
-	gchar *buf;
-	gchar *tag_open_ptr  = NULL;
-	gchar *tag_close_ptr = NULL;
 	gchar *search_string = NULL;
 
-	if (! strcmp (uri, "HOME")) {
+	gboolean gotta_free_name = FALSE;
+
+	if (strcmp (uri, "HOME") == 0) {
 		uri_new = g_filename_to_uri (g_get_home_dir (), NULL, NULL);
-		name    = g_strdup (C_("Home folder", "Home"));
-		icon    = "user-home";
-	}
-	else if (! strcmp (uri, "DOCUMENTS")) {
+		name = g_strdup (C_("Home folder", "Home"));
+		gotta_free_name = TRUE;
+		icon = "user-home";
+	} else if (strcmp (uri, "DOCUMENTS") == 0) {
 		path = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DOCUMENTS));
-		if (! path)
+		if (!path)
 			path = g_build_filename (g_get_home_dir (), "Documents", NULL);
 		name = _("Documents");
 		uri_new = g_filename_to_uri (path, NULL, NULL);
-		g_free (path);
-	}
-	else if (! strcmp (uri, "DESKTOP")) {
+	} else if (strcmp (uri, "DESKTOP") == 0) {
 		path = g_strdup (g_get_user_special_dir (G_USER_DIRECTORY_DESKTOP));
-		if (! path)
+		if (!path)
 			path = g_build_filename (g_get_home_dir (), "Desktop", NULL);
 		name = _("Desktop");
 		uri_new = g_filename_to_uri (path, NULL, NULL);
 		icon = "user-desktop";
-		g_free (path);
-	}
-	else if (! strcmp (uri, "file:///")) {
+	} else if (strcmp (uri, "file:///") == 0) {
 		icon = "drive-harddisk";
 		name = _("File System");
-	}
-	else if (! strcmp (uri, "network:")) {
+	} else if (strcmp (uri, "network:") == 0) {
 		icon = "network-workgroup";
 		name = _("Network Servers");
-	}
-	else if (g_str_has_prefix (uri, "x-caja-search")) {
+	} else if (g_str_has_prefix (uri, "x-caja-search")) {
 		icon = "system-search";
 
-		path = g_build_filename (g_get_home_dir (), ".caja", "searches", & uri [21], NULL);
+		path = g_build_filename (g_get_user_data_dir (), "caja", "searches", & uri [21], NULL);
 
 		if (g_file_test (path, G_FILE_TEST_EXISTS)) {
-			g_file_get_contents (path, & buf, NULL, NULL);
+			gchar *buf = NULL;
+			g_file_get_contents (path, &buf, NULL, NULL);
+
+			gchar *tag_open_ptr  = NULL;
+			gchar *tag_close_ptr = NULL;
 
 			if (buf) {
 				tag_open_ptr  = strstr (buf, "<text>");
@@ -1189,21 +1173,19 @@ create_dir_item (BookmarkAgent *this, const gchar *uri)
 
 			if (tag_open_ptr && tag_close_ptr) {
 				tag_close_ptr [0] = '\0';
-
-				search_string = g_strdup_printf ("\"%s\"", & tag_open_ptr [6]);
-
 				tag_close_ptr [0] = 'a';
+				search_string = g_strdup_printf ("\"%s\"", &tag_open_ptr[6]);
 			}
 
 			g_free (buf);
 		}
 
-		if (search_string)
+		if (search_string) {
 			name = search_string;
-		else
+			gotta_free_name = TRUE;
+		} else {
 			name = _("Search");
-
-		g_free (path);
+		}
 	}
 
 	if (icon)
@@ -1215,6 +1197,11 @@ create_dir_item (BookmarkAgent *this, const gchar *uri)
 	if (uri_new && libslab_strcmp (uri, uri_new))
 		g_bookmark_file_move_item (priv->store, uri, uri_new, NULL);
 
+	if (gotta_free_name) {
+		g_free (name);
+	}
+
+	g_free (path);
 	g_free (uri_new);
 }
 
