@@ -21,6 +21,7 @@
 #include "shell-window.h"
 
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 
 #include "app-resizer.h"
 
@@ -96,15 +97,6 @@ shell_window_handle_size_request (GtkWidget * widget, GtkRequisition * requisiti
 
 	gtk_widget_get_preferred_size (GTK_WIDGET (APP_RESIZER (app_data->category_layout)->child), &child_requisiton, NULL);
 
-	/*
-	Fixme - counting on this being called after the real size request is done.
-	seems to be that way but I don't know why. I would think I would need to explictly call it here first
-	printf("Enter - shell_window_handle_size_request\n");
-	printf("passed in width:%d, height:%d\n", requisition->width, requisition->height);
-	printf("left side width:%d\n", SHELL_WINDOW(widget)->_left_pane->requisition.width);
-	printf("right side width:%d\n", GTK_WIDGET(APP_RESIZER(app_data->category_layout)->child)->requisition.width);
-	*/
-
 	requisition->width += child_requisiton.width;
 
 	/* use the left side as a minimum height, if the right side is taller,
@@ -114,18 +106,20 @@ shell_window_handle_size_request (GtkWidget * widget, GtkRequisition * requisiti
 	if (height > requisition->height)
 	{
 		requisition->height =
-			MIN (((gfloat) gdk_screen_height () * SIZING_HEIGHT_PERCENT), height);
+			MIN (((gfloat) HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) * SIZING_HEIGHT_PERCENT), height);
 	}
 }
 
 void
 shell_window_set_contents (ShellWindow * shell, GtkWidget * left_pane, GtkWidget * right_pane)
 {
-	shell->_left_pane = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
-	shell->_right_pane = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
+	shell->_left_pane = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+	gtk_widget_set_margin_top (GTK_WIDGET (shell->_left_pane), 15);
+	gtk_widget_set_margin_bottom (GTK_WIDGET (shell->_left_pane), 15);
+	gtk_widget_set_margin_start (GTK_WIDGET (shell->_left_pane), 15);
+	gtk_widget_set_margin_end (GTK_WIDGET (shell->_left_pane), 15);
 
-	gtk_alignment_set_padding (GTK_ALIGNMENT (shell->_left_pane), 15, 15, 15, 15);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (shell->_right_pane), 0, 0, 0, 0);	/* space for vertical line */
+	shell->_right_pane = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
 	gtk_box_pack_start (shell->_hbox, shell->_left_pane, FALSE, FALSE, 0);
 	gtk_box_pack_start (shell->_hbox, shell->_right_pane, TRUE, TRUE, 0);	/* this one takes any extra space */
