@@ -25,6 +25,7 @@
 #include <math.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <gio/gio.h>
 
@@ -73,13 +74,8 @@ static gboolean     postpone_sensitize_cb          (DrwBreakWindow      *window)
 static gboolean     clock_timeout_cb               (DrwBreakWindow      *window);
 static void         postpone_clicked_cb            (GtkWidget           *button,
 						    GtkWidget           *window);
-#if GTK_CHECK_VERSION (3, 0, 0)
 static gboolean     label_draw_event_cb            (GtkLabel            *label,
 						    cairo_t             *cr,
-#else
-static gboolean     label_expose_event_cb          (GtkLabel            *label,
-						    GdkEventExpose      *event,
-#endif
 						    gpointer             user_data);
 static void         label_size_request_cb          (GtkLabel            *label,
 						    GtkRequisition      *requisition,
@@ -124,8 +120,6 @@ drw_break_window_init (DrwBreakWindow *window)
 	DrwBreakWindowPrivate *priv;
 	GtkWidget             *vbox;
 	GtkWidget             *hbox;
-	GtkWidget             *align;
-	GtkWidget             *monitor_box;
 	gchar                 *str;
 	GtkWidget             *outer_vbox;
 	GtkWidget             *button_box;
@@ -133,6 +127,7 @@ drw_break_window_init (DrwBreakWindow *window)
 
 	gint                   root_monitor = 0;
 	GdkScreen             *screen = NULL;
+	GdkDisplay            *display;
 	GdkRectangle           monitor;
 	gint                   right_padding;
 	gint                   bottom_padding;
@@ -154,48 +149,33 @@ drw_break_window_init (DrwBreakWindow *window)
 	gtk_window_set_modal (GTK_WINDOW (window), TRUE);
 
 	screen = gdk_screen_get_default ();
-	gdk_screen_get_monitor_geometry (screen, root_monitor, &monitor);
+	display = gdk_screen_get_display (screen);
+	gdk_monitor_get_geometry (gdk_display_get_monitor (display, root_monitor), &monitor);
 
 	gtk_window_set_default_size (GTK_WINDOW (window),
-				     gdk_screen_get_width (screen),
-				     gdk_screen_get_height (screen));
+				     WidthOfScreen (gdk_x11_screen_get_xscreen (screen)),
+				     HeightOfScreen (gdk_x11_screen_get_xscreen (screen)));
 
 	gtk_window_set_decorated (GTK_WINDOW (window), FALSE);
 	gtk_widget_set_app_paintable (GTK_WIDGET (window), TRUE);
 	drw_setup_background (GTK_WIDGET (window));
 
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_widget_show (align);
+	right_padding = WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) - monitor.width - monitor.x;
+	bottom_padding = HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) - monitor.height - monitor.y;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	outer_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
-	outer_vbox = gtk_vbox_new (FALSE, 0);
-#endif
+	gtk_widget_set_hexpand (outer_vbox, TRUE);
+	gtk_widget_set_vexpand (outer_vbox, TRUE);
+	gtk_widget_set_margin_top (outer_vbox, monitor.y);
+	gtk_widget_set_margin_bottom (outer_vbox, bottom_padding);
+	gtk_widget_set_margin_start (outer_vbox, monitor.x);
+	gtk_widget_set_margin_end (outer_vbox, right_padding);
 	gtk_widget_show (outer_vbox);
 
-	right_padding = gdk_screen_get_width (screen) - monitor.width - monitor.x;
-	bottom_padding = gdk_screen_get_height (screen) - monitor.height - monitor.y;
-
-	monitor_box = gtk_alignment_new (0.5, 0.5, 1, 1);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (monitor_box),
-				   monitor.y,
-				   bottom_padding,
-				   monitor.x,
-				   right_padding);
-	gtk_widget_show (monitor_box);
-
-	gtk_container_add (GTK_CONTAINER (window), monitor_box);
-	gtk_container_add (GTK_CONTAINER (monitor_box), outer_vbox);
-
-	gtk_box_pack_start (GTK_BOX (outer_vbox), align, TRUE, TRUE, 0);
+	gtk_container_add (GTK_CONTAINER (window), outer_vbox);
 
 	if (allow_postpone) {
-#if GTK_CHECK_VERSION (3, 0, 0)
 		button_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-		button_box = gtk_hbox_new (FALSE, 0);
-#endif
 		gtk_widget_show (button_box);
 
 		gtk_container_set_border_width (GTK_CONTAINER (button_box), 12);
@@ -228,30 +208,20 @@ drw_break_window_init (DrwBreakWindow *window)
 		gtk_box_pack_end (GTK_BOX (outer_vbox), button_box, FALSE, TRUE, 0);
 	}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
-	vbox = gtk_vbox_new (FALSE, 0);
-#endif
+	gtk_widget_set_halign (vbox, GTK_ALIGN_CENTER);
+	gtk_widget_set_valign (vbox, GTK_ALIGN_CENTER);
 	gtk_widget_show (vbox);
 
-	gtk_container_add (GTK_CONTAINER (align), vbox);
+	gtk_box_pack_start (GTK_BOX (outer_vbox), vbox, TRUE, TRUE, 0);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-	hbox = gtk_hbox_new (FALSE, 0);
-#endif
 	gtk_widget_show (hbox);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
 
 	priv->image = gtk_image_new_from_icon_name ("process-stop", GTK_ICON_SIZE_DIALOG);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_halign (priv->image, GTK_ALIGN_END);
 	gtk_widget_set_valign (priv->image, GTK_ALIGN_CENTER);
-#else
-	gtk_misc_set_alignment (GTK_MISC (priv->image), 1.0, 0.5);
-#endif
 	gtk_widget_show (priv->image);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->image, TRUE, TRUE, 8);
 
@@ -259,13 +229,8 @@ drw_break_window_init (DrwBreakWindow *window)
 	gtk_widget_show (priv->break_label);
 
 	g_signal_connect (priv->break_label,
-#if GTK_CHECK_VERSION (3, 0, 0)
 			  "draw",
 			  G_CALLBACK (label_draw_event_cb),
-#else
-			  "expose_event",
-			  G_CALLBACK (label_expose_event_cb),
-#endif
 			  NULL);
 
 	g_signal_connect_after (priv->break_label,
@@ -286,13 +251,8 @@ drw_break_window_init (DrwBreakWindow *window)
 	gtk_box_pack_start (GTK_BOX (vbox), priv->clock_label, TRUE, TRUE, 8);
 
 	g_signal_connect (priv->clock_label,
-#if GTK_CHECK_VERSION (3, 0, 0)
 			  "draw",
 			  G_CALLBACK (label_draw_event_cb),
-#else
-			  "expose_event",
-			  G_CALLBACK (label_expose_event_cb),
-#endif
 			  NULL);
 
 	g_signal_connect_after (priv->clock_label,
@@ -471,21 +431,20 @@ static gboolean
 grab_on_window (GdkWindow *window,
 		guint32    activate_time)
 {
-	if ((gdk_pointer_grab (window, TRUE,
-			       GDK_BUTTON_PRESS_MASK |
-			       GDK_BUTTON_RELEASE_MASK |
-			       GDK_POINTER_MOTION_MASK,
-			       NULL, NULL, activate_time) == 0)) {
-		if (gdk_keyboard_grab (window, TRUE,
-			       activate_time) == 0)
-			return TRUE;
-		else {
-			gdk_pointer_ungrab (activate_time);
-			return FALSE;
-		}
-	}
+	GdkDisplay *display;
+	GdkSeat *seat;
 
-	return FALSE;
+	display = gdk_window_get_display (window);
+	seat = gdk_display_get_default_seat (display);
+
+	return (gdk_seat_grab (seat,
+	                       window,
+	                       GDK_SEAT_CAPABILITY_ALL,
+	                       TRUE,
+	                       NULL,
+	                       NULL,
+	                       NULL,
+	                       NULL) == GDK_GRAB_SUCCESS);
 }
 
 static gboolean
@@ -574,19 +533,26 @@ get_layout_location (GtkLabel *label,
                      gint     *xp,
                      gint     *yp)
 {
-	GtkMisc        *misc;
 	GtkWidget      *widget;
 	GtkAllocation  widget_allocation;
 	GtkRequisition widget_requisition;
 	gfloat         xalign, yalign;
 	gint           x, y;
 	gint           xpad, ypad;
+	gint           margin_start, margin_end, margin_top, margin_bottom;
 
-	misc = GTK_MISC (label);
 	widget = GTK_WIDGET (label);
 
-	gtk_misc_get_alignment (misc, &xalign, &yalign);
-	gtk_misc_get_padding (misc, &xpad, &ypad);
+	xalign = gtk_label_get_xalign (GTK_LABEL (label));
+	yalign = gtk_label_get_yalign (GTK_LABEL (label));
+	margin_start = gtk_widget_get_margin_start (widget);
+	margin_end = gtk_widget_get_margin_end (widget);
+	margin_top = gtk_widget_get_margin_top (widget);
+	margin_bottom = gtk_widget_get_margin_bottom (widget);
+
+	xpad = margin_start + margin_end;
+	ypad = margin_top + margin_bottom;
+
 	gtk_widget_get_allocation (widget, &widget_allocation);
 	gtk_widget_get_requisition (widget, &widget_requisition);
 
@@ -610,7 +576,6 @@ get_layout_location (GtkLabel *label,
 	}
 }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static gboolean
 label_draw_event_cb (GtkLabel *label,
                      cairo_t  *cr,
@@ -636,48 +601,6 @@ label_draw_event_cb (GtkLabel *label,
 
 	return TRUE;
 }
-#else
-static gboolean
-label_expose_event_cb (GtkLabel       *label,
-                       GdkEventExpose *event,
-                       gpointer        user_data)
-{
-	gint       x, y;
-	GtkWidget *widget;
-	GdkWindow *window;
-	cairo_t *cr;
-
-	get_layout_location (label, &x, &y);
-
-	widget = GTK_WIDGET (label);
-	window = gtk_widget_get_window (widget);
-
-	cr = gdk_cairo_create (window);
-
-	gdk_cairo_rectangle (cr, &event->area);
-	cairo_clip (cr);
-
-	cairo_set_source_rgb (cr, 0, 0, 0);
-
-	cairo_move_to (cr, x + 1, y + 1);
-	pango_cairo_layout_path (cr, gtk_label_get_layout (label));
-	cairo_fill (cr);
-
-	cairo_destroy (cr);
-
-	gtk_paint_layout (gtk_widget_get_style (widget),
-			  window,
-			  gtk_widget_get_state (widget),
-			  FALSE,
-			  &event->area,
-			  widget,
-			  "label",
-			  x, y,
-			  gtk_label_get_layout (label));
-
-	return TRUE;
-}
-#endif
 
 static void
 label_size_request_cb (GtkLabel       *label,
